@@ -147,7 +147,7 @@ class AodhClientTest(base.ClientTestBase):
                                   ALARM_ID))
 
         # LIST
-        result = self.aodh('alarm', params="list")
+        result = self.aodh('alarm', params="list --filter all_projects=true")
         self.assertIn(ALARM_ID,
                       [r['alarm_id'] for r in self.parser.listing(result)])
         output_colums = ['alarm_id', 'type', 'name', 'state', 'severity',
@@ -247,7 +247,7 @@ class AodhClientTest(base.ClientTestBase):
                                   alarm_id))
 
         # LIST
-        result = self.aodh('alarm', params="list")
+        result = self.aodh('alarm', params="list --filter all_projects=true")
         self.assertIn(alarm_id,
                       [r['alarm_id'] for r in self.parser.listing(result)])
         output_colums = ['alarm_id', 'type', 'name', 'state', 'severity',
@@ -336,6 +336,52 @@ class AodhClientTest(base.ClientTestBase):
         self.assertEqual('ok', state_get['state'])
         self.aodh('alarm', params='delete %s' % alarm_id)
 
+    def test_update_type_event_composite(self):
+
+        res_id = uuidutils.generate_uuid()
+        # CREATE
+        result = self.aodh(u'alarm',
+                           params=(u"create --type event --name ev_alarm123"))
+        alarm = self.details_multiple(result)[0]
+        ALARM_ID = alarm['alarm_id']
+        self.assertEqual('ev_alarm123', alarm['name'])
+        self.assertEqual('*', alarm['event_type'])
+
+        # UPDATE TYPE TO COMPOSITE
+        result = self.aodh(
+            'alarm',
+            params=('update %s --type composite --composite-rule '
+                    '\'{"or":[{"threshold": 0.8, "metric": "cpu_util", '
+                    '"type": "gnocchi_resources_threshold", "resource_type": '
+                    '"generic", "resource_id": "%s", '
+                    '"aggregation_method": "mean"},'
+                    '{"and": [{"threshold": 200, "metric": "disk.iops", '
+                    '"type": "gnocchi_resources_threshold", "resource_type": '
+                    '"generic", "resource_id": "%s", '
+                    '"aggregation_method": "mean"},'
+                    '{"threshold": 1000, "metric": "memory",'
+                    '"type": "gnocchi_resources_threshold", "resource_type": '
+                    '"generic", "resource_id": "%s", '
+                    '"aggregation_method": "mean"}]}]}\'' %
+                    (ALARM_ID, res_id, res_id, res_id)))
+        alarm_updated = self.details_multiple(result)[0]
+        self.assertEqual(ALARM_ID, alarm_updated["alarm_id"])
+        self.assertEqual('composite', alarm_updated['type'])
+        self.assertIn('composite_rule', alarm_updated)
+
+        # UPDATE TYPE TO EVENT
+        result = self.aodh(
+            'alarm', params=("update %s --type event"
+                             % ALARM_ID))
+        alarm_updated = self.details_multiple(result)[0]
+        self.assertEqual(ALARM_ID, alarm_updated["alarm_id"])
+        self.assertEqual('event', alarm_updated['type'])
+        self.assertEqual('*', alarm_updated['event_type'])
+
+        # DELETE
+        result = self.aodh('alarm', params="delete %s" % ALARM_ID)
+        self.assertEqual("", result)
+
 
 class AodhClientGnocchiRulesTest(base.ClientTestBase):
 
@@ -425,6 +471,7 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
         # GET BY NAME
         result = self.aodh(
             'alarm', params="show --name alarm_gn1")
+        alarm_show = self.details_multiple(result)[0]
         self.assertEqual(ALARM_ID, alarm_show["alarm_id"])
         self.assertEqual(PROJECT_ID, alarm_show["project_id"])
         self.assertEqual('alarm_gn1', alarm_show['name'])
@@ -441,7 +488,7 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
                                   ALARM_ID))
 
         # LIST
-        result = self.aodh('alarm', params="list")
+        result = self.aodh('alarm', params="list --filter all_projects=true")
         self.assertIn(ALARM_ID,
                       [r['alarm_id'] for r in self.parser.listing(result)])
         output_colums = ['alarm_id', 'type', 'name', 'state', 'severity',
@@ -454,12 +501,13 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
         # LIST WITH PAGINATION
         # list with limit
         result = self.aodh('alarm',
-                           params="list --limit 1")
+                           params="list --filter all_projects=true --limit 1")
         alarm_list = self.parser.listing(result)
         self.assertEqual(1, len(alarm_list))
         # list with sort with key=name dir=asc
-        result = self.aodh('alarm',
-                           params="list --sort name:asc")
+        result = self.aodh(
+            'alarm',
+            params="list --filter all_projects=true --sort name:asc")
         names = [r['name'] for r in self.parser.listing(result)]
         sorted_name = sorted(names)
         self.assertEqual(sorted_name, names)
@@ -472,8 +520,10 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
                     "--aggregation-method last --project-id %s "
                     % (RESOURCE_ID, PROJECT_ID)))
         created_alarm_id = self.details_multiple(result)[0]['alarm_id']
-        result = self.aodh('alarm',
-                           params="list --sort name:asc --sort alarm_id:asc")
+        result = self.aodh(
+            'alarm',
+            params="list --filter all_projects=true --sort name:asc "
+                   "--sort alarm_id:asc")
         alarm_list = self.parser.listing(result)
         ids_with_same_name = []
         names = []
@@ -487,9 +537,10 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
         self.assertEqual(sorted_ids, ids_with_same_name)
         # list with sort with key=name dir=desc and with the marker equal to
         # the alarm_id of the alarm_th we created for this test.
-        result = self.aodh('alarm',
-                           params="list --sort name:desc "
-                                  "--marker %s" % created_alarm_id)
+        result = self.aodh(
+            'alarm',
+            params="list --filter all_projects=true --sort name:desc "
+                   "--marker %s" % created_alarm_id)
         self.assertIn('alarm_tc',
                       [r['name'] for r in self.parser.listing(result)])
         self.aodh('alarm', params="delete %s" % created_alarm_id)
@@ -584,7 +635,7 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
         self.assertEqual('generic', alarm_show['resource_type'])
 
         # LIST
-        result = self.aodh('alarm', params="list")
+        result = self.aodh('alarm', params="list --filter all_projects=true")
         self.assertIn(ALARM_ID,
                       [r['alarm_id'] for r in self.parser.listing(result)])
         output_colums = ['alarm_id', 'type', 'name', 'state', 'severity',
@@ -675,7 +726,7 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
         self.assertEqual('last', alarm_show['aggregation_method'])
 
         # LIST
-        result = self.aodh('alarm', params="list")
+        result = self.aodh('alarm', params="list --filter all_projects=true")
         self.assertIn(ALARM_ID,
                       [r['alarm_id'] for r in self.parser.listing(result)])
         for alarm_list in self.parser.listing(result):
@@ -713,3 +764,135 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
             self.assertEqual(sorted(output_colums), sorted(alarm_list.keys()))
         self.assertNotIn(ALARM_ID,
                          [r['alarm_id'] for r in self.parser.listing(result)])
+
+    def test_update_gnresthr_gnaggrresthr(self):
+
+        RESOURCE_ID = uuidutils.generate_uuid()
+        # CREATE
+        result = self.aodh(u'alarm',
+                           params=(u"create "
+                                   "--type gnocchi_resources_threshold "
+                                   "--name alarm_gn123 --metric cpu_util "
+                                   "--resource-id %s --threshold 80 "
+                                   "--resource-type generic "
+                                   "--aggregation-method last "
+                                   % RESOURCE_ID))
+        alarm = self.details_multiple(result)[0]
+        ALARM_ID = alarm['alarm_id']
+        self.assertEqual('alarm_gn123', alarm['name'])
+        self.assertEqual('cpu_util', alarm['metric'])
+        self.assertEqual('80.0', alarm['threshold'])
+        self.assertEqual('last', alarm['aggregation_method'])
+        self.assertEqual('generic', alarm['resource_type'])
+
+        # UPDATE TYPE TO GNOCCHI_AGGREGATION_BY_RESOURCES_THRESHOLD
+        result = self.aodh(
+            'alarm', params=("update %s --type "
+                             "gnocchi_aggregation_by_resources_threshold "
+                             "--metric cpu --threshold 90 "
+                             "--query "
+                             '\'{"=": {"creator": "cr3at0r"}}\' '
+                             "--resource-type generic "
+                             "--aggregation-method last "
+                             % ALARM_ID))
+        alarm_updated = self.details_multiple(result)[0]
+        self.assertEqual(ALARM_ID, alarm_updated["alarm_id"])
+        self.assertEqual('cpu', alarm_updated['metric'])
+        self.assertEqual('90.0', alarm_updated['threshold'])
+        self.assertEqual('last', alarm_updated['aggregation_method'])
+        self.assertEqual('generic', alarm_updated['resource_type'])
+        self.assertEqual('{"=": {"creator": "cr3at0r"}}',
+                         alarm_updated['query'])
+        self.assertEqual('gnocchi_aggregation_by_resources_threshold',
+                         alarm_updated['type'])
+
+        # UPDATE TYPE TO GNOCCHI_RESOURCES_THRESHOLD
+        result = self.aodh(
+            'alarm', params=("update %s "
+                             "--type gnocchi_resources_threshold "
+                             "--metric cpu_util "
+                             "--resource-id %s --threshold 80 "
+                             "--resource-type generic "
+                             "--aggregation-method last "
+                             % (ALARM_ID, RESOURCE_ID)))
+        alarm_updated = self.details_multiple(result)[0]
+        self.assertEqual(ALARM_ID, alarm_updated["alarm_id"])
+        self.assertEqual('cpu_util', alarm_updated['metric'])
+        self.assertEqual('80.0', alarm_updated['threshold'])
+        self.assertEqual('last', alarm_updated['aggregation_method'])
+        self.assertEqual('generic', alarm_updated['resource_type'])
+        self.assertEqual('gnocchi_resources_threshold',
+                         alarm_updated['type'])
+
+        # DELETE
+        result = self.aodh('alarm', params="delete %s" % ALARM_ID)
+        self.assertEqual("", result)
+
+    def test_update_gnaggrresthr_gnaggrmetricthr(self):
+
+        METRIC1 = 'cpu'
+        METRIC2 = 'cpu_util'
+
+        # CREATE
+        result = self.aodh(
+            u'alarm',
+            params=(u"create "
+                    "--type "
+                    "gnocchi_aggregation_by_resources_threshold "
+                    "--name alarm123 --metric cpu --threshold 80 "
+                    "--query "
+                    '\'{"=": {"creator": "cr3at0r"}}\' '
+                    "--resource-type generic "
+                    "--aggregation-method last "))
+        alarm = self.details_multiple(result)[0]
+        ALARM_ID = alarm['alarm_id']
+        self.assertEqual('alarm123', alarm['name'])
+        self.assertEqual('cpu', alarm['metric'])
+        self.assertEqual('80.0', alarm['threshold'])
+        self.assertEqual('last', alarm['aggregation_method'])
+        self.assertEqual('generic', alarm['resource_type'])
+        self.assertEqual('{"=": {"creator": "cr3at0r"}}',
+                         alarm['query'])
+
+        # UPDATE TYPE TO GNOCCHI_AGGREGATION_BY_METRICS_THRESHOLD
+        result = self.aodh(
+            'alarm', params=("update %s --type "
+                             "gnocchi_aggregation_by_metrics_threshold "
+                             "--metrics %s "
+                             "--metrics %s "
+                             "--threshold 80 "
+                             "--aggregation-method last"
+                             % (ALARM_ID, METRIC1, METRIC2)))
+        alarm_updated = self.details_multiple(result)[0]
+        self.assertEqual(ALARM_ID, alarm_updated["alarm_id"])
+        metrics = "[u'cpu', u'cpu_util']" if six.PY2 else "['cpu', 'cpu_util']"
+        self.assertEqual(metrics, alarm_updated['metrics'])
+        self.assertEqual('80.0', alarm_updated['threshold'])
+        self.assertEqual('last', alarm_updated['aggregation_method'])
+        self.assertEqual('gnocchi_aggregation_by_metrics_threshold',
+                         alarm_updated['type'])
+
+        # UPDATE TYPE TO GNOCCHI_AGGREGATION_BY_RESOURCES_THRESHOLD
+        result = self.aodh(
+            'alarm', params=("update %s --type "
+                             "gnocchi_aggregation_by_resources_threshold "
+                             "--metric cpu --threshold 80 "
+                             "--query "
+                             '\'{"=": {"creator": "cr3at0r"}}\' '
+                             "--resource-type generic "
+                             "--aggregation-method last "
+                             % ALARM_ID))
+        alarm_updated = self.details_multiple(result)[0]
+        self.assertEqual(ALARM_ID, alarm_updated["alarm_id"])
+        self.assertEqual('cpu', alarm_updated['metric'])
+        self.assertEqual('80.0', alarm_updated['threshold'])
+        self.assertEqual('last', alarm_updated['aggregation_method'])
+        self.assertEqual('generic', alarm_updated['resource_type'])
+        self.assertEqual('{"=": {"creator": "cr3at0r"}}',
+                         alarm_updated['query'])
+        self.assertEqual('gnocchi_aggregation_by_resources_threshold',
+                         alarm_updated['type'])
+
+        # DELETE
+        result = self.aodh('alarm', params="delete %s" % ALARM_ID)
+        self.assertEqual("", result)
