@@ -14,8 +14,8 @@
 #    under the License.
 
 import argparse
+from unittest import mock
 
-import mock
 import testtools
 
 from aodhclient.v2 import alarm_cli
@@ -42,13 +42,29 @@ class CliAlarmCreateTest(testtools.TestCase):
             '--aggregation-method', 'last',
             '--resource-type', 'generic',
             '--threshold', '80'
-            ])
+        ])
         self.cli_alarm_create._validate_args(test_parsed_args)
         mock_arg.assert_called_once_with(
             'gnocchi_resources_threshold requires --metric, '
             '--threshold, --resource-id, --resource-type and '
             '--aggregation-method')
 
+    @mock.patch.object(argparse.ArgumentParser, 'error')
+    def test_validate_args_threshold(self, mock_arg):
+        # Cover the test case of the method _validate_args for
+        # threshold
+        parser = self.cli_alarm_create.get_parser('aodh alarm create')
+        test_parsed_args = parser.parse_args([
+            '--name', 'threshold_test',
+            '--type', 'threshold',
+            '--threshold', '80'
+        ])
+        self.cli_alarm_create._validate_args(test_parsed_args)
+        mock_arg.assert_called_once_with(
+            'Threshold alarm requires -m/--meter-name and '
+            '--threshold parameters. Meter name can be '
+            'found in Ceilometer')
+
     @mock.patch.object(argparse.ArgumentParser, 'error')
     def test_validate_args_composite(self, mock_arg):
         # Cover the test case of the method _validate_args for
@@ -57,7 +73,7 @@ class CliAlarmCreateTest(testtools.TestCase):
         test_parsed_args = parser.parse_args([
             '--name', 'composite_test',
             '--type', 'composite'
-            ])
+        ])
         self.cli_alarm_create._validate_args(test_parsed_args)
         mock_arg.assert_called_once_with(
             'Composite alarm requires --composite-rule parameter')
@@ -74,7 +90,7 @@ class CliAlarmCreateTest(testtools.TestCase):
             '--aggregation-method', 'last',
             '--resource-type', 'generic',
             '--threshold', '80'
-            ])
+        ])
         self.cli_alarm_create._validate_args(test_parsed_args)
         mock_arg.assert_called_once_with(
             'gnocchi_aggregation_by_resources_threshold requires '
@@ -91,7 +107,7 @@ class CliAlarmCreateTest(testtools.TestCase):
             '--type', 'gnocchi_aggregation_by_metrics_threshold',
             '--resource-type', 'generic',
             '--threshold', '80'
-            ])
+        ])
         self.cli_alarm_create._validate_args(test_parsed_args)
         mock_arg.assert_called_once_with(
             'gnocchi_aggregation_by_metrics_threshold requires '
@@ -125,8 +141,11 @@ class CliAlarmCreateTest(testtools.TestCase):
             '--aggregation-method', 'last',
             '--metric', 'cpu',
             '--resource-id', '01919bbd-8b0e-451c-be28-abe250ae9c1c',
-            '--resource-type', 'generic'
-            ])
+            '--resource-type', 'generic',
+            '--stack-id', '0809ab348-8b0e-451c-be28-abe250ae9c1c',
+            '--pool-id', '79832aabf-343ba-be28-abe250ae9c1c',
+            '--autoscaling-group-id', 'abe250ae9c1c-79832aabf-343ba-be28'
+        ])
 
         # Output for the test
         alarm = {
@@ -153,6 +172,13 @@ class CliAlarmCreateTest(testtools.TestCase):
                            'type': '',
                            'value': 'fake-resource-id'}]
             },
+            'threshold_rule': {'comparison_operator': 'le',
+                               'evaluation_periods': 60,
+                               'query': [{'field': 'resource',
+                                          'op': 'eq',
+                                          'type': '',
+                                          'value': 'fake-resource-id'}],
+                               'threshold': 80.0},
             'gnocchi_resources_threshold_rule': {
                 'granularity': '60',
                 'metric': 'cpu',
@@ -171,6 +197,11 @@ class CliAlarmCreateTest(testtools.TestCase):
                 'threshold': 80.0,
                 'metrics': ['cpu'],
             },
+            'loadbalancer_member_health_rule': {
+                'autoscaling_group_id': 'abe250ae9c1c-79832aabf-343ba-be28',
+                'pool_id': '79832aabf-343ba-be28-abe250ae9c1c',
+                'stack_id': '0809ab348-8b0e-451c-be28-abe250ae9c1c'
+            },
             'gnocchi_aggregation_by_resources_threshold_rule': {
                 'granularity': '60',
                 'metric': 'cpu',
@@ -186,7 +217,7 @@ class CliAlarmCreateTest(testtools.TestCase):
             },
             'composite_rule': None,
             'type': 'event'
-            }
+        }
         alarm_rep = self.cli_alarm_create._alarm_from_args(test_parsed_args)
         self.assertEqual(alarm, alarm_rep)
 
